@@ -280,9 +280,7 @@ imgparam_window_on_markup_changed (GObject *object G_GNUC_UNUSED,
 	g_return_if_fail (priv != NULL);
 
 	if (hildon_window_get_is_topmost (HILDON_WINDOW(self->parent_window))) {
-		/*if (!(gdk_window_get_state (GTK_WIDGET (self->parent_window)->window) & GDK_WINDOW_STATE_FULLSCREEN)) {*/
-			imgparam_window_show (self);
-		/*}*/
+		imgparam_window_show (self);
 	}
 }
 
@@ -429,8 +427,8 @@ imgparam_window_new (GtkWindow *parent_window, const gchar *markup)
     g_signal_connect_after (parent_window, "size-allocate",
     		G_CALLBACK(imgparam_window_on_parent_size_changed), self);
 
-    g_signal_connect (parent_window, "window-state-event",
-			G_CALLBACK(imgparam_window_on_window_state_changed), self);
+    /* g_signal_connect (parent_window, "window-state-event",
+			G_CALLBACK(imgparam_window_on_window_state_changed), self); */
 
     if (HILDON_IS_WINDOW(parent_window)) {
         g_signal_connect (parent_window, "notify::is-topmost",
